| Title: | Client for 'GenderAPI.io' |
|---|---|
| Description: | Provides an interface to the 'GenderAPI.io' web service (<https://www.genderapi.io>) for determining gender from personal names, email addresses, or social media usernames. Functions are available to submit single or batch queries and retrieve additional information such as accuracy scores and country-specific gender predictions. This package simplifies integration of 'GenderAPI.io' into R workflows for data cleaning, user profiling, and analytics tasks. |
| Authors: | Onur Ozturk [aut, cre] |
| Maintainer: | Onur Ozturk <[email protected]> |
| License: | MIT + file LICENSE |
| Version: | 1.0.3 |
| Built: | 2026-05-12 06:19:59 UTC |
| Source: | https://github.com/genderapi/genderapi-r |
Get Gender by Email
get_gender_by_email(api_key, email, country = NULL, askToAI = FALSE)get_gender_by_email(api_key, email, country = NULL, askToAI = FALSE)
api_key |
Your GenderAPI.io API key. |
email |
Email string to check. |
country |
Optional two-letter country code (e.g. "US"). |
askToAI |
Logical. TRUE to force AI lookup, FALSE by default. |
A list with gender prediction result.
Get Gender by Email (Bulk)
get_gender_by_email_bulk(api_key, data)get_gender_by_email_bulk(api_key, data)
api_key |
Your GenderAPI.io API key. |
data |
A list of named lists. Each list can have: - email (string, required) - country (string, optional) - id (string or integer, optional) |
A list with bulk gender prediction results.
Get Gender by Name
get_gender_by_name( api_key, name, country = NULL, askToAI = FALSE, forceToGenderize = FALSE )get_gender_by_name( api_key, name, country = NULL, askToAI = FALSE, forceToGenderize = FALSE )
api_key |
Your GenderAPI.io API key. |
name |
Name string to check. |
country |
Optional two-letter country code (e.g. "US"). |
askToAI |
Logical. TRUE to force AI lookup, FALSE by default. |
forceToGenderize |
Logical. TRUE to force analysis of nicknames. |
A list with gender prediction result.
Get Gender by Name (Bulk)
get_gender_by_name_bulk(api_key, data)get_gender_by_name_bulk(api_key, data)
api_key |
Your GenderAPI.io API key. |
data |
A list of named lists. Each list can have: - name (string, required) - country (string, optional) - id (string or integer, optional) |
A list with bulk gender prediction results.
Get Gender by Username
get_gender_by_username( api_key, username, country = NULL, askToAI = FALSE, forceToGenderize = FALSE )get_gender_by_username( api_key, username, country = NULL, askToAI = FALSE, forceToGenderize = FALSE )
api_key |
Your GenderAPI.io API key. |
username |
Username string to check. |
country |
Optional two-letter country code (e.g. "US"). |
askToAI |
Logical. TRUE to force AI lookup, FALSE by default. |
forceToGenderize |
Logical. TRUE to force analysis of nicknames. |
A list with gender prediction result.
Get Gender by Username (Bulk)
get_gender_by_username_bulk(api_key, data)get_gender_by_username_bulk(api_key, data)
api_key |
Your GenderAPI.io API key. |
data |
A list of named lists. Each list can have: - username (string, required) - country (string, optional) - id (string or integer, optional) |
A list with bulk gender prediction results.